@@ -119,7 +119,7 @@ def library(name, session=None, package="stsim", addons=None, template=None,
                 raise ValueError(
                     f'The addon package {addons} is not installed')
             
-            args = ["--create", "--addon", "--lib=%s" % name + ".ssim",
+            args = ["--create", "--addon", "--lib=%s" % loc,
                     "--name=%s" % addons]
             session._Session__call_console(args)
             
@@ -132,6 +132,9 @@ def library(name, session=None, package="stsim", addons=None, template=None,
         re1 = str(re1)
         if "The Library already exists" in re1:
             pass
+        else:
+            raise RuntimeError(re1)
+
     
     library_up_to_date = False
     try:
