@@ -299,7 +299,7 @@ def test_library_delete():
     
 def test_library_save_datasheet():
     
-    myLibrary = ps.library(name="Test")
+    myLibrary = ps.library(name="Test", overwrite=True, forceUpdate=True)
     
     # Test save_datasheet method
     with pytest.raises(
@@ -317,19 +317,34 @@ def test_library_save_datasheet():
         
     with pytest.raises(TypeError, match="data must be a pandas DataFrame"):
         myLibrary.save_datasheet(name="test", data=1)
+
+    with pytest.raises(TypeError, match="append must be a Logical"):
+        myLibrary.save_datasheet(name="test", data=pd.DataFrame(), append="True")
+
+    with pytest.raises(TypeError, match="force must be a Logical"):
+        myLibrary.save_datasheet(name="test", data=pd.DataFrame(), force="True")
         
     with pytest.raises(TypeError, match="scope must be a String"):
         myLibrary.save_datasheet(name="test", data=pd.DataFrame(), scope=1)
         
     with pytest.raises(RuntimeError,
                        match="The data sheet does not exist: stsim_test"):
-        myLibrary.save_datasheet(name="test", data=pd.DataFrame())
+        myLibrary.save_datasheet(name="test", data=pd.DataFrame(), force=True)
         
     with pytest.raises(
             RuntimeError,
             match="The header references a column that does not belong"):
         random_df = pd.DataFrame({"col1": [1], "col2": [2]})
         myLibrary.save_datasheet(name="core_Backup", data=random_df)
+
+    with pytest.raises(
+        RuntimeError,
+        match ="The transfer method is not valid for a single row data sheet."
+    ):
+        myLibDF = pd.DataFrame({"IncludeInput": ["Yes"],
+                                "IncludeOutput": ["Yes"], 
+                                "BeforeUpdate": ["Yes"]})
+        myLibrary.save_datasheet(name="core_Backup", data=myLibDF, append=True)
     
     initial_core_backup = myLibrary.datasheets(name="core_Backup")
     assert initial_core_backup["IncludeOutput"].isna().values[0]
@@ -343,6 +358,18 @@ def test_library_save_datasheet():
     myLibrary.save_datasheet(name="core_Backup", data=initial_core_backup)
     modified_core_backup = myLibrary.datasheets(name="core_Backup")
     assert (modified_core_backup["IncludeOutput"] == "No").item() 
+
+    myLibDF = pd.DataFrame({"IncludeInput": ["Yes"],
+                            "IncludeOutput": ["Yes"], 
+                            "BeforeUpdate": ["Yes"]})
+    myLibrary.save_datasheet(name="core_Backup", data=myLibDF)
+    assert myLibrary.datasheets(name="core_Backup").equals(myLibDF)
+
+    myLibrary.save_datasheet(name="core_Backup", data=pd.DataFrame())
+    assert myLibrary.datasheets(name="core_Backup").equals(myLibDF)
+
+    myLibrary.save_datasheet(name="core_Backup", data=pd.DataFrame(), force=True)
+    assert myLibrary.datasheets(name="core_Backup").empty
     
 def test_library_run():
     
@@ -372,7 +399,9 @@ def test_library_run():
                                       "Scenario", None, None, False, False, 1)
     runcontrol["MaximumIteration"] = 2
     runcontrol["MaximumTimestep"] = 2
-    myLibrary.save_datasheet("RunControl", runcontrol, "Scenario", 1)
+    myLibrary.save_datasheet("RunControl", runcontrol, 
+                             False, False,
+                             "Scenario", 1)
     
     myLibrary.run()
     assert len(myLibrary.scenarios()) == 2
@@ -494,8 +523,12 @@ def test_project_datasheets():
     
 def test_project_save_datasheet():
     
-    myLibrary = ps.library(name="Test", package="helloworldSpatial")
+    myLibrary = ps.library(name="Test", package="helloworldSpatial",
+                           overwrite=True, forceUpdate=True)
     myProject = myLibrary.projects(name="Definitions")
+    myLibrary.scenarios(name="test")
+    myLibrary.scenarios(name="test2")
+    myLibrary.scenarios(name="test3")
     
     # Test save_datasheet
     with pytest.raises(
@@ -520,6 +553,28 @@ def test_project_save_datasheet():
     myProject.save_datasheet(name="core_AutoGenTag", data=test_datasheet)
     assert myProject.datasheets(name="core_AutoGenTag").empty is False
 
+    myProjDF = pd.DataFrame({'ScheduledScenarioID': [1], "Order": [1]})
+    myProject.save_datasheet(name = "core_RunSchedulerScenario", data = myProjDF)
+    assert myProject.datasheets(name = "core_RunSchedulerScenario").equals(myProjDF)
+
+    myProjDF2 = pd.DataFrame({'ScheduledScenarioID': [2], "Order": [2]})
+    myProject.save_datasheet(name = "core_RunSchedulerScenario", data = myProjDF2, append=False, force=True)
+    assert len(myProject.datasheets(name = "core_RunSchedulerScenario")) == 1
+
+    myProjDF2 = pd.DataFrame({'ScheduledScenarioID': [1], "Order": [1]})
+    myProject.save_datasheet(name = "core_RunSchedulerScenario", data = myProjDF2, append=True, force=True)
+    assert len(myProject.datasheets(name = "core_RunSchedulerScenario")) == 2
+
+    myProjDF2 = pd.DataFrame({'ScheduledScenarioID': [3], "Order": [3]})
+    myProject.save_datasheet(name = "core_RunSchedulerScenario", data = myProjDF2, append=False)
+    assert len(myProject.datasheets(name = "core_RunSchedulerScenario")) == 2
+
+    myProject.save_datasheet(name = "core_RunSchedulerScenario", data = pd.DataFrame())
+    assert len(myProject.datasheets(name = "core_RunSchedulerScenario")) == 2
+
+    myProject.save_datasheet(name = "core_RunSchedulerScenario", data = pd.DataFrame(), force=True)
+    assert myProject.datasheets(name = "core_RunSchedulerScenario").empty
+
 def test_project_copy_delete():
     
     myLibrary = ps.library(name="Test", package="helloworldSpatial")
@@ -609,10 +664,10 @@ def test_scenario_datasheets():
 
 def test_scenario_save_datasheet():
 
-    myLibrary = ps.library(name="ds_test", package="helloworldSpatial",
-                           overwrite=True, template="example-library",
+    myLibrary = ps.library(name="ds_test", package="helloworld",
+                           overwrite=True,
                            forceUpdate=True)
-    myScenario = myLibrary.scenarios(sid=1)    
+    myScenario = myLibrary.scenarios(name="test")    
 
     # Test save_datasheet
     with pytest.raises(
@@ -630,16 +685,20 @@ def test_scenario_save_datasheet():
         
     with pytest.raises(TypeError, match="data must be a pandas DataFrame"):
         myScenario.save_datasheet(name="test", data=1)
-        
-    runcontrol = myScenario.datasheets(name="RunControl")
-    runcontrol["MaximumIteration"] = 2
-    runcontrol["MaximumTimestep"] = 2
-    myScenario.save_datasheet("RunControl", runcontrol)
 
-    assert myScenario.datasheets(
-        name="RunControl")["MaximumIteration"].item() == 2
-    assert myScenario.datasheets(
-        name="RunControl")["MaximumTimestep"].item() == 2
+    myDataFrame = pd.DataFrame({'x': [1.0], 'a': [2]})
+    myScenario.save_datasheet(name="helloworld_InputDatasheet", data=myDataFrame)
+    assert myScenario.datasheets(name="helloworld_InputDatasheet").equals(myDataFrame)
+
+    myDataFrame2 = pd.DataFrame({'x': [2.0], 'a': [2]})
+    myScenario.save_datasheet(name="helloworld_InputDatasheet", data=myDataFrame2, append=True)
+    assert len(myScenario.datasheets(name="helloworld_InputDatasheet")) == 2
+
+    myScenario.save_datasheet(name="helloworld_InputDatasheet", data=myDataFrame2, append=False)
+    assert len(myScenario.datasheets(name="helloworld_InputDatasheet")) == 1
+
+    myScenario.save_datasheet(name="helloworld_InputDatasheet", data=pd.DataFrame())
+    assert myScenario.datasheets(name="helloworld_InputDatasheet").empty
     
 def test_scenario_run_and_results():
     
